# PyOVO

PyOVO provides a set of tools for physical simulation and optimization. Given that we want to collect and simplify the introduction of frequently used functions in our research, this package is designed to be lightweight and easy-to-use.
